@@ -1,6 +1,7 @@
 #!/bin/bash
 #
 # Copyright © 2012-2018 Dr. Tobias Quathamer <toddy@debian.org>
+#           © 2025 Dr. Helge Kreutzmann <debian@helgefjell.de>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -59,7 +60,7 @@ for language in "${language_list[@]}"; do
 
     # Extract all translators from the copyright headers for the given language
     # FIXME This misses the files in archive/*
-    files=$(find po/${lang_code}/man? -name "*po" | sort)
+    files=$(find po/${lang_code}/man? po/${lang_code}/archive/man? -name "*po" | sort)
     # files="$files $(find po/secondary-*/man? -name "*po" | sort)"
     for translation in $files; do
 	    # Use the header up until the first msgid
