@@ -72,7 +72,7 @@ localized="$distribution/$localized"
 if [ ! -f noaddendum ]; then
     # Create the addendum for this manpage
     addendum=$(mktemp)
-    ./generate-addendum.sh "$translation" "$addendum"
+    ./generate-addendum.sh "$translation" "$addendum" "$master"
 fi
 
 # Create a separate .po file for this distribution,
