@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 # Copyright © 2010-2017 Dr. Tobias Quathamer <toddy@debian.org>
-#             2022 Dr. Helge Kreutzmann <debian@helgefjell.de>
+#             2022,2025 Dr. Helge Kreutzmann <debian@helgefjell.de>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@
 
 translation="$1"
 addendum="$2"
+masterfile="$3"
 
-
-ismdoc=$(grep -l $translation ../mdoc.cache)
+ismdoc=$(grep -Rl "\.Sh NAME" $masterfile)
 
 # Use the header up until the first msgid
 # and remove the comment character
