@@ -56,9 +56,9 @@ po4a-updatepo -f man \
         --no-deprecation \
 	--option groff_code=verbatim \
 	--option generated \
-	--option untranslated="}1,Ds,zY,zZ,Ee,ES,dT,FN,NE,NS,EX,EE,Id,rstReportMargin,INDENT,UNINDENT,UN,a.RE,\|\|,Vb,Ve" \
+	--option untranslated="}1,Ds,zY,zZ,Ee,ES,dT,FN,NE,NS,EX,EE,Id,rstReportMargin,INDENT,UNINDENT,UN,a.RE,\|\|,Vb,Ve,bP,Ex,EX,FN,q,Sp,Sx,tq,tQ,R$" \
 	--option unknown_macros=untranslated \
-	--option inline="MR" \
+	--option inline="MR,MTO,URL" \
 	--option no_wrap="Vb:Ve" \
 	--master "$tdir/$distribution/$manpage" -M utf-8 \
 	-p $tdir/tmp.pot
